@@ -11,8 +11,8 @@ def timehash(private_key, public_key, hextime):
     return m.hexdigest()
 
 class TimeHashVerifier(Verifier):
-    __futurelimit = 180
-    __pastlimit = 300
+    def __init__(self, limits=(300, 180)):
+        self.__pastlimit, self.__futurelimit = limits
 
     def divide_verifier_data(self, raw_data, secret_key):
         return raw_data.rsplit('$', 1)
@@ -26,7 +26,11 @@ class TimeHashVerifier(Verifier):
         timehex = others[:8]
         hexhash = others[8:]
         check_hexhash = timehash(private_key, public_key, timehex)
-        return hexhash == check_hexhash
+        if not hexhash == check_hexhash:
+            return False
+        given_time = int(timehex, 16)
+        self.derived_context = {'time': given_time}
+        return -self.__pastlimit <= time.time() - given_time <= self.__futurelimit
 
     def merge_verifier_data(self, verifier, raw_data, secret_key):
         return '$'.join((verifier, raw_data))
@@ -37,3 +41,4 @@ class TimeHashVerifier(Verifier):
         hextime = '%8x' % inow
         hexhash = timehash(private_key, public_key, hextime)
         return ''.join((public_key, '$', hextime, hexhash))
+
